##  Background
On March 24, 2025, we rolled out translation corrections to all workspaces related to the capitalization of letters for several default fields in the meta model (for example, “End of Life” replaced “End of life”). However, for the OData integration, we continued exporting the former values to ensure continued support with the BookmarkService.svc endpoint.
